@@ -1,23 +1,23 @@
 # Colors and functions for working with colors
 
 color = {
-  'red': [255, 0, 0],
-  'pink': [255, 127, 127],
-  'yellow': [255, 255, 0],
-  'green': [0, 255, 0],
-  'cyan': [0, 255, 255],
-  'blue': [0, 0, 255],
-  'purple': [255, 0, 255],
-  'orange': [255, 127, 0],
-  'aqua': [0, 255, 127],
-  'white': [255, 255, 255],
-  'black': [0, 0, 0],
-  'gray': [127, 127, 127]
+  _('red'): [255, 0, 0],
+  _('pink'): [255, 127, 127],
+  _('yellow'): [255, 255, 0],
+  _('green'): [0, 255, 0],
+  _('cyan'): [0, 255, 255],
+  _('blue'): [0, 0, 255],
+  _('purple'): [255, 0, 255],
+  _('orange'): [255, 127, 0],
+  _('aqua'): [0, 255, 127],
+  _('white'): [255, 255, 255],
+  _('black'): [0, 0, 0],
+  _('gray'): [127, 127, 127]
   }
 
 # We use these a lot, so save lookup time
-WHITE = color["white"]
-BLACK = color["black"]
+WHITE = color[_("white")]
+BLACK = color[_("black")]
 
 def brighten(color, diff = 64):
   return [min(x + diff, 255) for x in color]
