@@ -12,11 +12,14 @@ import dance
 import random
 import util
 import options
+import unicodedata
 
 from constants import *
 from interface import *
 from courses import CRSFile
 from pygame.mixer import music
+from fonttheme import FontTheme
+from i18n import *
 
 NO_BANNER = os.path.join(image_path, "no-banner.png")
 
@@ -33,13 +36,13 @@ SORT_NAMES = ["mix", "title"]
 NUM_SORTS = len(SORT_NAMES)
 
 CS_HELP = [
-  "Up / Down: Change song selection",
-  "Left / Right: Change difficulty setting",
-  "Enter / Up Right: Open a folder or start a course",
-  "Escape / Up Left: Close a folder or exit",
-  "Tab / Select: Go to a random course",
-  "Start: Switch to Options screen",
-  "F11: Toggle fullscreen - S: Change the sort mode",
+  _("Up / Down: Change song selection"),
+  _("Left / Right: Change difficulty setting"),
+  _("Enter / Up Right: Open a folder or start a course"),
+  _("Escape / Up Left: Close a folder or exit"),
+  _("Tab / Select: Go to a random course"),
+  _("Start: Switch to Options screen"),
+  _("F11: Toggle fullscreen - S: Change the sort mode"),
   ]
 
 class CourseDisplay(object):
@@ -65,42 +68,42 @@ class CourseDisplay(object):
     i = 1
     for name, diff, mods in self.course.songs:
       if "*" in name: name, subtitle = "??????????", ""
-      elif name[0] == "BEST":
+      elif name[0] == _("BEST"):
         song = recordkeys.get(records.best(name[1], diff, game))
         if song:
-          subtitle = (song.info["subtitle"] or "") + (" (Best #%d)" % name[1])
+          subtitle = (song.info["subtitle"] or "") + (_(" (Best #%d)") % name[1])
           name = song.info["title"]
         else:
-          name = "Player's Best Unavailable"
-          subtitle = "(You need to play more songs!)"
+          name = _("Player's Best Unavailable")
+          subtitle = _("(You need to play more songs!)")
 
-      elif name[0] == "WORST":
+      elif name[0] == _("WORST"):
         song = recordkeys.get(records.worst(name[1], diff, game))
         if song:
-          subtitle = (song.info["subtitle"] or "") + (" (Worst #%d)" % name[1])
+          subtitle = (song.info["subtitle"] or "") + (_(" (Worst #%d)") % name[1])
           name = song.info["title"]
         else:
-          name = "Player's Worst Unavailable"
-          subtitle = "(You need to play more songs!)"
+          name = _("Player's Worst Unavailable")
+          subtitle = _("(You need to play more songs!)")
 
-      elif name[0] == "LIKES":
+      elif name[0] == _("LIKES"):
         song = recordkeys.get(records.like(name[1], diff, game))
         if song:
           subtitle = (song.info["subtitle"] or "") + (" (Likes #%d)" % name[1])
           name = song.info["title"]
         else:
-          name = "Player's Likes Unavailable"
-          subtitle = "(You need to play more songs!)"
+          name = _("Player's Likes Unavailable")
+          subtitle = _("(You need to play more songs!)")
 
-      elif name[0] == "DISLIKES":
+      elif name[0] == _("DISLIKES"):
         song = recordkeys.get(records.dislike(name[1], diff, game))
         if song:
           subtitle = ((song.info["subtitle"] or "") +
-                      (" (Dislikes #%d)" % name[1]))
+                      (_(" (Dislikes #%d)") % name[1]))
           name = song.info["title"]
         else:
-          name = "Player's Dislikes Unavailable"
-          subtitle = "(You need to play more songs!)"
+          name = _("Player's Dislikes Unavailable")
+          subtitle = _("(You need to play more songs!)")
 
       else: name, subtitle = util.find_subtitle(name.split("/")[-1])
 
@@ -112,8 +115,8 @@ class CourseDisplay(object):
 
   def render(self):
     if self.banner: return
-    font = fontfx.WrapFont(28, 320)
-    small_font = fontfx.WrapFont(18, 250)
+    font = fontfx.WrapFont(FontTheme.Crs_song_title, 320)
+    small_font = fontfx.WrapFont(FontTheme.Crs_song_subtitle, 250)
     ls = font.get_linesize()
     y = ls * 3
     for name, subtitle, diff in self._songs:
@@ -124,9 +127,8 @@ class CourseDisplay(object):
     self.image.fill([0, 0, 0, 0])
 
     y_off = 0
-    for i in range(len(self._songs)):
+    for name,subtitle,diff in self._songs:
       t3 = None
-      name, subtitle, diff = self._songs[i]
       t1 = font.render(name, color = colors.WHITE, indent = "    ")
       if subtitle:
         t3 = small_font.render(subtitle, color = [190, 190, 190],
@@ -134,7 +136,8 @@ class CourseDisplay(object):
 
       if isinstance(diff, list): d = diff[0]
       else: d = diff
-      t2 = fontfx.shadow(d[0], 28, DIFF_COLORS.get(d, colors.WHITE))
+      
+      t2 = fontfx.shadow(d[0], FontTheme.Crs_song_title, DIFF_COLORS.get(d, colors.WHITE))
 
       r1 = t1.get_rect()
       r2 = t2.get_rect()
@@ -172,7 +175,7 @@ class FolderDisplay(object):
   def render(self):
     if self.banner: return
 
-    name = self.name.encode("ascii", "ignore")
+    name = self.name
     for path in [rc_path, pydance_path]:
       filename = os.path.join(path, "banners", self._type, name+".png")
       if os.path.exists(filename):
@@ -202,14 +205,14 @@ class CourseSelector(InterfaceWindow):
     self._config = dict(game_config)
     self._configs = []
 
-    self._list = ListBox(pygame.font.Font(None, 28),
+    self._list = ListBox(FontTheme.Crs_list,
                          [255, 255, 255], 32, 10, 256, [373, 150])
     if len(self._courses) > 60 and mainconfig["folders"]:
       self._create_folders()
       self._create_folder_list()
     else:
       self._folders = None
-      self._base_text = "All Courses"
+      self._base_text = _("All Courses")
       self._courses.sort(SORTS[SORT_NAMES[mainconfig["sortmode"] % NUM_SORTS]])
       self._list.set_items([s.name for s in self._courses])
 
@@ -222,12 +225,12 @@ class CourseSelector(InterfaceWindow):
       self._configs.append(dict(player_config))
 
     ActiveIndicator([368, 306], height = 32, width = 266).add(self._sprites)
-    HelpText(CS_HELP, [255, 255, 255], [0, 0, 0], pygame.font.Font(None, 20),
+    HelpText(CS_HELP, [255, 255, 255], [0, 0, 0], FontTheme.help,
              [186, 20]).add(self._sprites)
 
     self._list_gfx = ScrollingImage(self._course.image, [15, 80], 390)
-    self._coursetitle = TextDisplay(28, [345, 28], [20, 56])
-    self._title = TextDisplay(30, [240, 28], [377, 27])
+    self._coursetitle = TextDisplay('Crs_course_name', [345, 28], [20, 56])
+    self._title = TextDisplay('Crs_course_list_head', [240, 28], [377, 27])
     self._banner = ImageDisplay(self._course.banner, [373, 56])
     self._sprites.add([self._list, self._list_gfx, self._title,
                        self._coursetitle, self._banner])
@@ -364,7 +367,7 @@ class CourseSelector(InterfaceWindow):
     self._courses = new_courses
     self._list.set_items([s.fullname for s in self._courses])
     
-    self._base_text = "Sort by %s" % sort.capitalize()
+    self._base_text = _("Sort by %s") % sort.capitalize()
     
   def _create_course_list(self, folder):
     sort = SORT_NAMES[mainconfig["sortmode"] % NUM_SORTS]
