@@ -13,14 +13,17 @@ from constants import *
 
 import ui
 
+from i18n import *
+from fonttheme import FontTheme
+
 ENDLESS_HELP = [
-  "Left: Make the songs that will be played easier",
-  "Right: Make the songs that will be played harder",
-  "Up: Select difficulty by name",
-  "Down: Select difficulty by rating",
-  "Enter / Up Right: Start playing songs until you fail",
-  "Escape / Up Left: Go back to the game selection screen",
-  "Start: Go to the options screen / F11: Toggle fullscreen",
+  _("Left: Make the songs that will be played easier"),
+  _("Right: Make the songs that will be played harder"),
+  _("Up: Select difficulty by name"),
+  _("Down: Select difficulty by rating"),
+  _("Enter / Up Right: Start playing songs until you fail"),
+  _("Escape / Up Left: Go back to the game selection screen"),
+  _("Start: Go to the options screen / F11: Toggle fullscreen"),
   ]
 
 def check_constraints(constraints, diff):
@@ -32,7 +35,7 @@ class EndlessDiffDisplay(pygame.sprite.Sprite):
   def __init__(self, pid, constraint):
     pygame.sprite.Sprite.__init__(self)
     self._c = constraint
-    self._ptext = fontfx.shadow("Player %d" % (pid + 1), 60, colors.WHITE)
+    self._ptext = fontfx.shadow(_("Player %d") % (pid + 1), FontTheme.Endless_player, colors.WHITE)
     self._pr = self._ptext.get_rect()
     self._centerx = 160 + 320 * pid
     self._oldval = None
@@ -41,11 +44,12 @@ class EndlessDiffDisplay(pygame.sprite.Sprite):
   def update(self, time):
     if self._oldval != (self._c.kind, self._c.value):
       if self._c.kind == "name":
-        ctext = fontfx.shadow("Select by Difficulty", 48, colors.WHITE)
-        vtext = fontfx.shadow(self._c.value.capitalize(), 40, colors.WHITE)
+        ctext = fontfx.shadow(_("Select by Difficulty"), FontTheme.Endless_filter_by, colors.WHITE)
+	i18ndifficulty = _(self._c.value)
+	vtext = fontfx.shadow(i18ndifficulty.capitalize(), FontTheme.Endless_filter_range, colors.WHITE)
       elif self._c.kind == "number":
-        ctext = fontfx.shadow("Select by Rating", 48, colors.WHITE)
-        vtext = fontfx.shadow("Between %d and %d" % self._c.value, 40,
+        ctext = fontfx.shadow(_("Select by Rating"), FontTheme.Endless_filter_by, colors.WHITE)
+        vtext = fontfx.shadow(_("Between %d and %d") % self._c.value, FontTheme.Endless_filter_range,
                                  colors.WHITE)
       self.image = pygame.Surface([300, 400])
       cr = ctext.get_rect()
@@ -107,8 +111,8 @@ class FakePlaylist(object):
   def next(self):
     if len(self.songs) == 0:
       error.ErrorMessage(self.screen,
-                         "The difficulty settings you chose result " +
-                         "in no songs being available to play.")
+                         _("The difficulty settings you chose result ") +
+                         _("in no songs being available to play."))
       raise StopIteration
     elif len(self.working) == 0: self.working = self.songs[:]
     i = random.randint(0, len(self.working) - 1)
@@ -142,8 +146,8 @@ class Endless(InterfaceWindow):
     diffs.sort(util.difficulty_sort)
 
     if len(diffs) == 0:
-      error.ErrorMessage(screen, "You need more songs to play Endless Mode. " +
-                         "Otherwise, it's just really boring.")
+      error.ErrorMessage(screen, _("You need more songs to play Endless Mode. ") +
+                         _("Otherwise, it's just really boring."))
       return
 
     mainconfig["autofail"] = 1
@@ -162,7 +166,7 @@ class Endless(InterfaceWindow):
       EndlessDiffDisplay(i, c).add(self._sprites)
 
     self._sprites.add(HelpText(ENDLESS_HELP, [255, 255, 255], [0, 0, 0],
-                               pygame.font.Font(None, 22), [320, 20]))
+                               FontTheme.help, [320, 20]))
 
     music.load(os.path.join(sound_path, "menu.ogg"))
     music.play(4, 0.0)
