@@ -4,6 +4,7 @@
 import os
 import dircache
 import string
+import codecs
 
 import games
 import util
@@ -75,7 +76,12 @@ class GenericFile(object):
       if len(parts) == 2: time = 60 * int(parts[0]) + float(parts[1])
       elif len(parts) == 3: ## M:SS:CS
         time = int(parts[0]) + float(parts[1]) + float(parts[2]) / 100
-    elif "." in string: time = float(string) # seconds in a float value
+    elif "." in string:
+      if string.count('.')==2: # M.SS.CS
+        parts = string.split('.')
+        time = 60 * int(parts[0]) + float(parts[1]) + float(parts[2])/100
+      else: time = float(string) # seconds in a float value
+      
     else: time = int(string) / 1000.0 # no punctuation means in milliseconds
     return offset + time
 
@@ -204,6 +210,10 @@ class MSDFile(GenericFile):
     GenericFile.__init__(self, filename, need_steps)
     lines = []
     f = file(filename)
+
+    # If there is a BOM, skip it. Otherwise, don't.
+    if f.read(3) != codecs.BOM_UTF8: f.seek(0)
+
     for line in f:
       if line.find("//") != -1: line = line[:line.find("//")]
       line = line.strip()
@@ -235,8 +245,8 @@ class MSDFile(GenericFile):
         time = self.parse_time(line[1:line.index("]")])
         lyr = line[line.index("]") + 1:].split("|")
         lyr.reverse()
-        self.lyrics.extend([(time, i + 1, lyr[i]) for i in range(len(lyr)) if
-                            lyr[i] != ""])
+        self.lyrics.extend([(time, i + 1, l) for i,l in enumerate(lyr) if
+                            l != ""])
 
   # Return a list of all the images in the directory, sorted by file size
   def find_images(self):
@@ -459,8 +469,8 @@ class DWIFile(MSDFile):
             # Some DWI files have things like ...2!(2...
             step_type = DWIFile.modes[possible]
             holdstep = dwifile_steps[steps.pop(0)]
-          for i in range(len(holdstep)):
-            if holdstep[i]: step[i] |= 3
+          for i,h in enumerate(holdstep):
+            if h: step[i] |= 3
         steplist.append([step_type] + step)
         current_time += step_type
 
@@ -603,13 +613,14 @@ class SMFile(MSDFile):
         if gametype in games.COUPLE:
           step1 = [note]
           step2 = [note]
-          step1.extend([SMFile.step[int(s)] for s in sd[0:count/2]])
-          step2.extend([SMFile.step[int(s)] for s in sd[count/2:]])
+          # Ugly hack to ignore mines and other "letters" (for now).
+          step1.extend([SMFile.step[int(s.translate(ZERO_ALPHA))] for s in sd[0:count/2]])
+          step2.extend([SMFile.step[int(s.translate(ZERO_ALPHA))] for s in sd[count/2:]])
           stepdata[0].append(step1)
           stepdata[1].append(step2)
         else:
           step = [note]
-          step.extend([SMFile.step[int(s)] for s in sd])
+          step.extend([SMFile.step[int(s.translate(ZERO_ALPHA))] for s in sd])
           stepdata.append(step)
 
         beat += note / 4.0
@@ -779,11 +790,11 @@ class SongItem(object):
              ("song.wav", KSFFile))
 
   defaults = { "valid": 1,
-               "mix": "No Mix",
-               "title": "Untitled",
+               "mix": _("No Mix"),
+               "title": _("Untitled"),
                "subtitle": "",
-               "artist": "Unknown",
-               "author": "Unknown",
+               "artist": _("Unknown"),
+               "author": _("Unknown"),
                "endat": 0.0,
                "preview": (45.0, 10.0),
                "startat": 0.0,
@@ -797,19 +808,19 @@ class SongItem(object):
         song = pair[1](filename, need_steps)
         break
     if song == None:
-      raise RuntimeError(filename + " is an unsupported format.")
+      raise RuntimeError(filename + _(" is an unsupported format."))
     self.info = song.info
 
     # Sanity checks
     for k in ["bpm", "filename"]:
       if k not in self.info:
-        raise RuntimeError(filename + " is missing: " + k)
+        raise RuntimeError(filename + _(" is missing: ") + k)
 
     for k in ["subtitle", "title", "artist", "author", "mix"]:
       try:
         if k in self.info: self.info[k] = self.info[k].decode("utf-8")
       except UnicodeError:
-        print "W: Non-Unicode key in %s: %s" % (filename, k)
+        print _("W: Non-Unicode key in %s: %s") % (filename, k)
         self.info[k] = self.info[k].decode("ascii", "ignore")
 
     # Default values
