@@ -7,7 +7,10 @@ import colors
 import fontfx
 import random
 
+
 from constants import *
+from fonttheme import FontTheme
+from i18n import *
 
 # Make an outlined box. The size is given without the 4 pixel border.
 # This usually gets alphaed before stuff gets put in it.
@@ -26,8 +29,9 @@ def make_box(color = [111, 255, 148], size = [130, 40]):
 
 def folder_name(name, type):
   if type == "mix": return name
-  elif type == "bpm": return "%s BPM" % name
-  else: return "%s: %s" % (type.capitalize(), name)
+  elif type == "bpm": return "%s BPM" % _(name)
+  else: 
+    return "%s: %s" % (_(type).capitalize(), name)
 
 def load_banner(filename, box = True):
   banner = pygame.image.load(filename)
@@ -53,16 +57,16 @@ def load_banner(filename, box = True):
 
 # Just display a text string, within a specific width.
 class TextDisplay(pygame.sprite.Sprite):
-  def __init__(self, font, size, midleft, str = " "):
+  def __init__(self, purpose, size, midleft, str = " "):
     pygame.sprite.Sprite.__init__(self)
     self._text = str
-    self._font = font
+    self._purpose = purpose
     self._size = size
     self._midleft = midleft
     self._render()
 
   def _render(self):
-    font = fontfx.max_size(self._text, self._size[0], self._font)
+    font = FontTheme.font(self._purpose, self._text, self._size[0])
     img = fontfx.shadow(self._text, font, [255, 255, 255])
     self.image = img
     self.rect = self.image.get_rect()
@@ -336,17 +340,18 @@ class ActiveIndicator(pygame.sprite.Sprite):
   def update(self, time):
     self.image.set_alpha(int(255 * (0.3 + (math.sin(time / 720.0)**2 / 3.0))))
 
-# Box to indicate the current difficulty level.
+# Box to indicate the current difficulty level and rating.
 class DifficultyBox(pygame.sprite.Sprite):
   def __init__(self, center):
     pygame.sprite.Sprite.__init__(self)
     self._topleft = [center[0]-65, center[1]-20]
 
   def set(self, diff, color, feet, grade):
-    f = pygame.font.Font(None, 24)
+    f = FontTheme.diffbox
     self.image = make_box(color)
 
-    t1 = fontfx.shadow(diff, f, [255, 255, 255])
+    #diff has to be translated: _( ) (BEGINNER, etc.)
+    t1 = fontfx.shadow(_(diff), f, [255, 255, 255])
     r1 = t1.get_rect()
     r1.center = [self.image.get_width()/2, 14]
 
@@ -446,7 +451,7 @@ class BannerDisplay(pygame.sprite.Sprite):
     self._next_update = -1
     self._delta = 5
     self._idx = 1
-    self._bpmdisplay = BPMDisplay(pygame.font.Font(None, 24), [60, 180])
+    self._bpmdisplay = BPMDisplay(FontTheme.BannerDisp_BPM, [60, 180])
 
   def set_song(self, song):
     c1 = [255, 255, 255]
@@ -456,12 +461,12 @@ class BannerDisplay(pygame.sprite.Sprite):
     song.render()
 
     self._title = fontfx.shadow(song.info["title"],
-                                fontfx.max_size(song.info["title"], 340, 60),
+                                FontTheme.font('BannerDisp_title',song.info["title"],340),
                                 c1)
     self._r_t = self._title.get_rect()
     self._r_t.center = [179, 240]
     self._artist = fontfx.shadow(song.info["artist"],
-                                 fontfx.max_size(song.info["artist"], 250, 40),
+                                 FontTheme.font('BannerDisp_artist',song.info["artist"], 250),
                                  c1)
 
     self._r_a = self._artist.get_rect()
@@ -469,8 +474,7 @@ class BannerDisplay(pygame.sprite.Sprite):
 
     if song.info["subtitle"]:
       self._subtitle = fontfx.shadow(song.info["subtitle"],
-                                     fontfx.max_size(song.info["subtitle"],
-                                                     300, 24),
+                                     FontTheme.font('BannerDisp_subtitle',song.info["subtitle"],300),
 
                                      c1)
       self._r_s = self._subtitle.get_rect()
@@ -561,18 +565,16 @@ class InterfaceWindow(object):
 
 NO_BANNER = os.path.join(image_path, "no-banner.png")
 
-class SongItemDisplay(object):
+class AbstractItemDisplay(object):
   no_banner = make_box(size = [256, 80])
   tmp = pygame.image.load(NO_BANNER)
   tmp.set_colorkey(tmp.get_at([0, 0]))
   no_banner.blit(tmp, [4, 4])
-
   def __init__(self, song): # A SongItem object
     self._song = song
-    self.difficulty = song.difficulty
     self.info = song.info
     self.filename = song.filename
-    self.diff_list = song.diff_list
+    
     self.banner = None
     self.isfolder = False
     self.folder = {}
@@ -588,3 +590,21 @@ class SongItemDisplay(object):
     if self.info["cdtitle"]:
       self.cdtitle = pygame.image.load(self.info["cdtitle"])
     else: self.cdtitle = pygame.Surface([0, 0])
+
+class SongItemDisplay(AbstractItemDisplay):
+  def __init__(self, song, game):
+    AbstractItemDisplay.__init__(self, song)
+    self.difficulty = song.difficulty[game]
+    self.diff_list = song.diff_list[game]
+    self.danceitems = {}
+
+class DanceItemDisplay(AbstractItemDisplay):
+  def __init__(self, song, game, diff):
+    AbstractItemDisplay.__init__(self, song)
+    self.difficulty = {diff:song.difficulty[game][diff]}
+    self.diff_list = [diff]
+    self.diff = diff
+    self.songitem = None
+
+
+  
