@@ -15,7 +15,9 @@ import lifebars
 from constants import *
 from interface import *
 
-ON_OFF = [(0, "Off", ""), (1, "On", "")]
+from i18n import *
+
+ON_OFF = [(0, _("Off"), ""), (1, _("On"), "")]
 
 # Description gets assigned 2 both times.
 PP, NAME, DESCRIPTION, VALUES = range(4)
@@ -29,138 +31,138 @@ OPTIONS = {
   # 3. A list of 3-tuples (a, b, c) where a is the value of the option.
   #    b is the string to display for that value, and c is a string
   #    describing the value.
-  "speed": (True, "Speed",
-            "Adjust the speed at which the arrows scroll across the screen.",
-            zip([0.25, 0.33, 0.5, 0.75, 1, 1.5, 2, 3, 4, 5, 8],
-                ["0.25x", "0.33x", "0.50x", "0.75x", "1.0x", "1.5x", "2.0x",
-                 "3.0x", "4.0x", "5.0x", "8.0x"],
-                [""] * 11)
+  "speed": (True, _("Speed"),
+            _("Adjust the speed at which the arrows scroll across the screen."),
+            zip([0.25, 0.33, 0.5, 0.75, 1, 1.5, 2, 2.5, 3, 4, 5, 8, -200, -300, -400, -500, -600, -700, -800],
+                ["0.25x", "0.33x", "0.50x", "0.75x", "1.0x", "1.5x", "2.0x", "2.5x",
+                 "3.0x", "4.0x", "5.0x", "8.0x", "200bpm", "300bpm", "400bpm", "500bpm", "600bpm", "700bpm", "800bpm"],
+                [""] * 12 + [_("Arrows scroll at 200bpm."), _("Arrows scroll at 300bpm."), _("Arrows scroll at 400bpm."), _("Arrows scroll at 500bpm."), _("Arrows scroll at 600bpm."), _("Arrows scroll at 700bpm."), _("Arrows scroll at 800bpm.")])
             ),
-  "transform": (True, "Transform",
-                "Change the step patterns for the song.",
+  "transform": (True, _("Transform"),
+                _("Change the step patterns for the song."),
                 zip([0, 1, 2, 3, -1, -2],
-                    ["Normal", "Mirror", "Left", "Right", "Shuffle", "Random"],
-                    ["", "Rotate the steps 180 degrees.",
-                     "Rotate the steps 90 degrees to the left.",
-                     "Rotate the steps 90 degrees to the right.",
-                     "Swap all arrows from one direction to another.",
-                     "Use totally random directions."])
+                    [_("Normal"), _("Mirror"), _("Left"), _("Right"), _("Shuffle"), _("Random")],
+                    ["", _("Rotate the steps 180 degrees."),
+                     _("Rotate the steps 90 degrees to the left."),
+                     _("Rotate the steps 90 degrees to the right."),
+                     _("Swap all arrows from one direction to another."),
+                     _("Use totally random directions.")])
                 ),
-  "size": (True, "Add/Remove Steps",
-           "Add or remove arrows from step patterns.",
+  "size": (True, _("Add/Remove Steps"),
+           _("Add or remove arrows from step patterns."),
            zip([1, 2, 0, 3, 4, 5],
-               ["Tiny", "Little", "Normal", "Big", "Quick", "Skippy"],
-               ["Only dance to on-beat notes.",
-                "Only dance to on-beat and half-beat notes.",
-                "", "Add half-beat steps between on-beat ones.",
-                "Add steps between half-beat ones.",
-                "Add gallops between on-beat steps."])
+               [_("Tiny"), _("Little"), _("Normal"), _("Big"), _("Quick"), _("Skippy")],
+               [_("Only dance to on-beat notes."),
+                _("Only dance to on-beat and half-beat notes."),
+                "", _("Add half-beat steps between on-beat ones."),
+                _("Add steps between half-beat ones."),
+                _("Add gallops between on-beat steps.")])
            ),
-  "fade": (True, "Fade",
-           "Fade arrows in or out while they scroll.",
+  "fade": (True, _("Fade"),
+           _("Fade arrows in or out while they scroll."),
            zip([0, 1, 2, 3, 4, 5],
-               ["Normal", "Sudden", "Hidden", "Peek", "Cycle", "Stealth"],
-               ["", "Only display arrows near the top.",
-                "Only display arrows near the bottom.",
-                "Only display arrows near the middle.",
-                "Blink arrows in and out.",
-                "No arrows are displayed."])
+               [_("Normal"), _("Sudden"), _("Hidden"), _("Peek"), _("Cycle"), _("Stealth")],
+               ["", _("Only display arrows near the top."),
+                _("Only display arrows near the bottom."),
+                _("Only display arrows near the middle."),
+                _("Blink arrows in and out."),
+                _("No arrows are displayed.")])
            ),
-  "accel": (True, "Acceleration",
-            "Accelerate or decelerate arrows.",
+  "accel": (True, _("Acceleration"),
+            _("Accelerate or decelerate arrows."),
             zip([2, 0, 1],
-                ["Brake", "Normal", "Boost"],
-                ["Decelerate near the top", "", "Accelerate near the top."])
+                [_("Brake"), _("Normal"), _("Boost")],
+                [_("Decelerate near the top"), "", _("Accelerate near the top.")])
             ),
-  "scale": (True, "Size",
-            "Change arrow sizes.",
+  "scale": (True, _("Size"),
+            _("Change arrow sizes."),
             zip([0, 1, 2],
-                ["Shrink", "Normal", "Grow"],
-                ["Smaller arrows near the top.", "",
-                 "Smaller arrows near the bottom."])
+                [_("Shrink"), _("Normal"), _("Grow")],
+                [_("Smaller arrows near the top."), "",
+                 _("Smaller arrows near the bottom.")])
             ),
-  "scrollstyle": (True, "Direction",
-                  "Change the direction arrows scroll.",
+  "scrollstyle": (True, _("Direction"),
+                  _("Change the direction arrows scroll."),
                   zip([0, 1, 2],
-                      ["Normal", "Reverse", "Center"],
-                      ["Arrows go from bottom to top.",
-                       "Arrows go from top to bottom.",
-                       "Arrows go from the top and bottom to the center."])
+                      [_("Normal"), _("Reverse"), _("Center")],
+                      [_("Arrows go from bottom to top."),
+                       _("Arrows go from top to bottom."),
+                       _("Arrows go from the top and bottom to the center.")])
                   ),
-  "jumps": (True, "Jumps",
-            "Turn jumps off, or add more.",
+  "jumps": (True, _("Jumps"),
+            _("Turn jumps off, or add more."),
             zip([0, 1, 2],
-                ["Off", "On", "Wide"],
-                ["Remove jumps from the song.", "",
-                 "Add jumps on every on-beat step."])
+                [_("Off"), _("On"), _("Wide")],
+                [_("Remove jumps from the song."), "",
+                 _("Add jumps on every on-beat step.")])
             ),
-  "spin": (True, "Spin",
-           "Rotate arrows as they go up the screen.",
+  "spin": (True, _("Spin"),
+           _("Rotate arrows as they go up the screen."),
            ON_OFF),
-  "colortype": (True, "Colors",
-                "Use colors of arrows to indicate the beat.",
+  "colortype": (True, _("Colors"),
+                _("Use colors of arrows to indicate the beat."),
                 zip([1, 4],
-                    ["Flat", "Normal"],
-                    ["All arrows are the same.",
-                     "Different arrows have different colors."])
+                    [_("Flat"), _("Normal")],
+                    [_("All arrows are the same."),
+                     _("Different arrows have different colors.")])
                 ),
-  "dark": (True, "Dark",
-           "Don't display the top arrows.",
+  "dark": (True, _("Dark"),
+           _("Don't display the top arrows."),
            ON_OFF),
-  "holds": (True, "Holds",
-            "Allow hold ('freeze') arrows in songs.",
+  "holds": (True, _("Holds"),
+            _("Allow hold ('freeze') arrows in songs."),
             ON_OFF),
-  "scoring": (False, "Scoring",
-              "The scoring algorithm.",
+  "scoring": (False, _("Scoring"),
+              _("The scoring algorithm."),
               scores.score_opt),
-  "grade": (False, "Grades",
-            "The grading algorithm.",
+  "grade": (False, _("Grades"),
+            _("The grading algorithm."),
             grades.grade_opt),
-  "combo": (False, "Combos",
-             "How your combo increases.",
+  "combo": (False, _("Combos"),
+             _("How your combo increases."),
              combos.combo_opt),
-  "judge": (False, "Judging Method",
-            "How your steps are judged.",
+  "judge": (False, _("Judging Method"),
+            _("How your steps are judged."),
             judge.judge_opt),
-  "judgescale": (False, "Judging Windows",
-                 "The margin of error for your steps.",
+  "judgescale": (False, _("Judging Windows"),
+                 _("The margin of error for your steps."),
                  zip([2.0 - 0.2 * i for i in range(10)],
                      [str(i) for i in range(10)],
-                     ["Window is twice normal size.",
-                      "Window is 9/5 normal size.",
-                      "Window is 8/5 normal size.",
-                      "Window is 7/5 normal size.",
-                      "Window is 6/5 normal size.", "",
-                      "Window is 4/5 normal size.",
-                      "Window is 3/5 normal size.",
-                      "Window is 2/5 normal size.",
-                      "Window is 1/5 normal size."])
+                     [_("Window is twice normal size."),
+                      _("Window is 9/5 normal size."),
+                      _("Window is 8/5 normal size."),
+                      _("Window is 7/5 normal size."),
+                      _("Window is 6/5 normal size."), "",
+                      _("Window is 4/5 normal size."),
+                      _("Window is 3/5 normal size."),
+                      _("Window is 2/5 normal size."),
+                      _("Window is 1/5 normal size.")])
                  ),
 
-  "life": (False, "Life",
-                 "Increase or decrease your amount of (non-battery) life.",
-                 [(0.25, "Undead", "Life is 1/4 the usual amount."),
-                  (0.50, "Very Low", "Life is 1/2 the usual amount."),
-                  (0.75, "Low", "Life is 3/4 the usual amount."),
-                  (1, "Normal", ""),
-                  (1.25, "High", "Life is 5/4 the usual amount."),
-                  (1.50, "Very High", "Life is 3/2 the usual amount."),
-                  (1.75, "Lazarus", "Life is 7/4 the usual amount.")]
+  "life": (False, _("Life"),
+                 _("Increase or decrease your amount of (non-battery) life."),
+                 [(0.25, _("Undead"), _("Life is 1/4 the usual amount.")),
+                  (0.50, _("Very Low"), _("Life is 1/2 the usual amount.")),
+                  (0.75, _("Low"), _("Life is 3/4 the usual amount.")),
+                  (1, _("Normal"), ""),
+                  (1.25, _("High"), _("Life is 5/4 the usual amount.")),
+                  (1.50, _("Very High"), _("Life is 3/2 the usual amount.")),
+                  (1.75, _("Lazarus"), _("Life is 7/4 the usual amount."))]
                  ),
-  "lifebar": (False, "Lifebar",
-              "The kind of lifebar used.",
+  "lifebar": (False, _("Lifebar"),
+              _("The kind of lifebar used."),
               lifebars.lifebar_opt),
-  "onilives": (False, "Oni Lives",
-               "The initial / maximum life in Battery mode.",
+  "onilives": (False, _("Oni Lives"),
+               _("The initial / maximum life in Battery mode."),
                [(i, str(i), "") for i in range(1, 9)]),
-  "secret": (False, "Secret Arrows",
-             "Secret arrow display",
-             [(0, "Off", "Disable secret arrows."),
-              (1, "Invisible", "Enable but don't display them."),
-              (2, "Faint", "Show secret arrows faintly.")]
+  "secret": (False, _("Secret Arrows"),
+             _("Secret arrow display"),
+             [(0, _("Off"), _("Disable secret arrows.")),
+              (1, _("Invisible"), _("Enable but don't display them.")),
+              (2, _("Faint"), _("Show secret arrows faintly."))]
              ),
-  "battle": (False, "Battle Mode",
-             "Arrows start in the center and float outwards.",
+  "battle": (False, _("Battle Mode"),
+             _("Arrows start in the center and float outwards."),
              ON_OFF),
   }
             
@@ -171,10 +173,10 @@ OPTS = [ "speed", "transform", "size", "fade", "accel", "scale",
          ]
 
 O_HELP = [
-  "Up / Down: Select option",
-  "Left / Right: Change value",
-  "Start: Return to song selector",
-  "F11: Toggle fullscreen"
+  _("Up / Down: Select option"),
+  _("Left / Right: Change value"),
+  _("Start: Return to song selector"),
+  _("F11: Toggle fullscreen")
   ]
 
 def index_of(value, name):
@@ -194,7 +196,7 @@ class OptionSelect(pygame.sprite.Sprite):
     self._center = center
     self._end_time = pygame.time.get_ticks()
     self._needs_update = True
-    self._font = pygame.font.Font(None, 30)
+    self._font = FontTheme.Opts_choices
     self._render(pygame.time.get_ticks())
 
   def update(self, time):
@@ -233,7 +235,7 @@ class OptionSelect(pygame.sprite.Sprite):
     else: offset = 0
 
     t = fontfx.shadow(self._possible[self._index],
-                      pygame.font.Font(None, 30), [255, 255, 255])
+                      FontTheme.Opts_choices, [255, 255, 255])
     r = t.get_rect()
     r.center = [215 + offset, 20]
     self.image.blit(t, r)
@@ -242,7 +244,7 @@ class OptionSelect(pygame.sprite.Sprite):
     idx = self._index - 1
     while idx >= 0 and r.left > 0:
       t = fontfx.shadow(self._possible[idx],
-                        pygame.font.Font(None, 30), [255, 255, 255])
+                        FontTheme.Opts_choices, [255, 255, 255])
       t2 = pygame.Surface(t.get_size())
       t2.blit(t, [0, 0])
       t2.set_colorkey(t2.get_at([0, 0]))
@@ -258,7 +260,7 @@ class OptionSelect(pygame.sprite.Sprite):
     r = old_r
     while idx < len(self._possible) and r.right < 430:
       t = fontfx.shadow(self._possible[idx],
-                        pygame.font.Font(None, 30), [255, 255, 255])
+                        FontTheme.Opts_choices, [255, 255, 255])
       t2 = pygame.Surface(t.get_size())
       t2.blit(t, [0, 0])
       t2.set_colorkey(t2.get_at([0, 0]))
@@ -283,35 +285,35 @@ class OptionScreen(InterfaceWindow):
     self._config = game_config
     self._players = len(self._configs)
 
-    self._lists = [ListBox(pygame.font.Font(None, 24), [255, 255, 255],
+    self._lists = [ListBox(FontTheme.Opts_list, [255, 255, 255],
                            25, 9, 176, [10, 10])]
-    self._text = [WrapTextDisplay(28, 430, [198, 165], centered = True,
+    self._text = [WrapTextDisplay(FontTheme.Opts_description, 430, [198, 165], centered = True,
                                   str = OPTIONS[self.optlist[0]][DESCRIPTION])]    
     val = self._configs[0][self.optlist[0]]
     names = [v[NAME] for v in OPTIONS[self.optlist[0]][VALUES]]
     desc = OPTIONS[self.optlist[0]][VALUES][index_of(val, self.optlist[0])][DESCRIPTION]
-    self._text2 = [WrapTextDisplay(22, 430, [198, 105], centered = True,
+    self._text2 = [WrapTextDisplay(FontTheme.Opts_choice_description, 430, [198, 105], centered = True,
                                   str = desc)]
     self._displayers = [OptionSelect(names, [415, 40],
                                      index_of(val, self.optlist[0]))]
     self._index = [0]
     ActiveIndicator([5, 106], height = 25, width = 185).add(self._sprites)
     if self._players == 2:
-      self._lists.append(ListBox(pygame.font.Font(None, 24), [255, 255, 255],
+      self._lists.append(ListBox(FontTheme.Opts_list, [255, 255, 255],
                                  25, 9, 176, [453, 246]))
       self._index.append(0)
-      self._text.append(WrapTextDisplay(28, 430, [10, 275], centered = True,
+      self._text.append(WrapTextDisplay(FontTheme.Opts_description, 430, [10, 275], centered = True,
                                         str = OPTIONS[self.optlist[0]][DESCRIPTION]))
       ActiveIndicator([448, 341], height = 25, width = 185).add(self._sprites)
       val = self._configs[1][self.optlist[0]]
       desc = OPTIONS[self.optlist[0]][VALUES][index_of(val, self.optlist[0])][DESCRIPTION]
-      self._text2.append(WrapTextDisplay(22, 430, [10, 350], centered = True,
+      self._text2.append(WrapTextDisplay(FontTheme.Opts_choice_description, 430, [10, 350], centered = True,
                                          str = desc))
       self._displayers.append(OptionSelect(names, [220, 440],
                                            index_of(val, self.optlist[0])))
 
     HelpText(O_HELP, [255, 255, 255], [0, 0, 0],
-             pygame.font.Font(None, 22), [320, 241]).add(self._sprites)
+             FontTheme.help, [320, 241]).add(self._sprites)
     self._sprites.add(self._lists + self._displayers + self._text +
                       self._text2)
 
