@@ -21,6 +21,8 @@ from listener import Listener
 
 from pygame.sprite import RenderUpdates, RenderClear
 
+from fonttheme import FontTheme
+
 # This class keeps an ordered list of sprites in addition to the dict,
 # so we can draw in the order the sprites were added.
 class OrderedRenderUpdates(RenderClear):
@@ -93,8 +95,8 @@ class HoldJudgeDisp(Listener, pygame.sprite.Sprite):
     self.image.fill([0, 0, 0])
     self.image.set_colorkey([0, 0, 0], RLEACCEL)
 
-    self.okimg = fontfx.shadefade("OK", 28, 3, [48, 24], [112, 224, 112])
-    self.ngimg = fontfx.shadefade("NG", 28, 3, [48, 24], [224, 112, 112])
+    self.okimg = fontfx.shadefade(_("OK"), FontTheme.Dance_hold_judgment, 3, [48, 24], [112, 224, 112])
+    self.ngimg = fontfx.shadefade(_("NG"), FontTheme.Dance_hold_judgment, 3, [48, 24], [224, 112, 112])
 
     self.rect = self.image.get_rect()
     if player.scrollstyle == 2: self.rect.top = 228
@@ -120,13 +122,13 @@ class HoldJudgeDisp(Listener, pygame.sprite.Sprite):
     self.slotnow[self.game.dirs.index(direction)] = self.ngimg
     
   def update(self, curtime):
-    for i in range(len(self.slotnow)):
+    for i,s in enumerate(self.slotnow):
       if (curtime - self.slothit[i] > 0.5):
-        self.slotnow[i] = self.space
-      if self.slotnow[i] != self.slotold[i]:
+        s = self.slotnow[i] = self.space
+      if s != self.slotold[i]:
         x = (i * self.game.width)
-        self.image.blit(self.slotnow[i], [x, 0])
-        self.slotold[i] = self.slotnow[i]
+        self.image.blit(s, [x, 0])
+        self.slotold[i] = s
 
 class JudgingDisp(Listener, pygame.sprite.Sprite):
   def __init__(self, playernum, game):
@@ -139,25 +141,25 @@ class JudgingDisp(Listener, pygame.sprite.Sprite):
     self._bottom = 320
     self._centerx = game.sprite_center + (playernum * game.player_offset)
         
-    tx = FONTS[48].size("MARVELOUS")[0] + 4
-    marvelous = fontfx.shadefade("MARVELOUS", 48, 4, [tx, 40], [224, 224, 224])
+    tx = FontTheme.Dance_step_judgment.size(_("MARVELOUS"))[0] + 4
+    marvelous = fontfx.shadefade(_("MARVELOUS"), FontTheme.Dance_step_judgment, 4, [tx, 40], [224, 224, 224])
 
-    tx = FONTS[48].size("PERFECT")[0] + 4
-    perfect = fontfx.shadefade("PERFECT", 48, 4, [tx, 40], [224, 224, 32])
+    tx = FontTheme.Dance_step_judgment.size(_("PERFECT"))[0] + 4
+    perfect = fontfx.shadefade(_("PERFECT"), FontTheme.Dance_step_judgment, 4, [tx, 40], [224, 224, 32])
 
-    tx = FONTS[48].size("GREAT")[0] + 4
-    great = fontfx.shadefade("GREAT", 48, 4, [tx, 40], [32, 224, 32])
+    tx = FontTheme.Dance_step_judgment.size(_("GREAT"))[0] + 4
+    great = fontfx.shadefade(_("GREAT"), FontTheme.Dance_step_judgment, 4, [tx, 40], [32, 224, 32])
 
-    tx = FONTS[48].size("OKAY")[0] + 4
-    okay = fontfx.shadefade("OKAY", 48, 4, [tx, 40], [32, 32, 224])
+    tx = FontTheme.Dance_step_judgment.size(_("OKAY"))[0] + 4
+    okay = fontfx.shadefade(_("OKAY"), FontTheme.Dance_step_judgment, 4, [tx, 40], [32, 32, 224])
 
-    tx = FONTS[48].size("BOO")[0] + 4
-    boo = fontfx.shadefade("BOO", 48, 4, [tx, 40], [96, 64, 32])
+    tx = FontTheme.Dance_step_judgment.size(_("BOO"))[0] + 4
+    boo = fontfx.shadefade(_("BOO"), FontTheme.Dance_step_judgment, 4, [tx, 40], [96, 64, 32])
 
-    tx = FONTS[48].size("MISS")[0]+4
-    miss = fontfx.shadefade("MISS", 48, 4, [tx, 40], [224, 32, 32])
+    tx = FontTheme.Dance_step_judgment.size(_("MISS"))[0]+4
+    miss = fontfx.shadefade(_("MISS"), FontTheme.Dance_step_judgment, 4, [tx, 40], [224, 32, 32])
 
-    self._space = FONTS[48].render(" ", True, [0, 0, 0])
+    self._space = FontTheme.Dance_step_judgment.render(" ", True, [0, 0, 0])
 
     marvelous.set_colorkey(marvelous.get_at([0, 0]), RLEACCEL)
     perfect.set_colorkey(perfect.get_at([0, 0]), RLEACCEL)
@@ -210,6 +212,11 @@ class Player(object):
 
     self.__dict__.update(config)
 
+    if self.speed < 0:
+      self.target_bpm = -self.speed
+    else:
+      self.target_bpm = None
+
     self.game = game
 
     if self.scrollstyle == 2: self.top = 240 - game.width / 2
@@ -393,11 +400,10 @@ class Player(object):
     self.toparr_group.update(curtime, curbeat)
 
   def should_hold(self, steps, direction, curtime):
-    l = steps.holdinfo
-    for i in range(len(l)):
-      if l[i][0] == self.game.dirs.index(direction):
-        if ((curtime - 15.0/steps.playingbpm > l[i][1])
-            and (curtime < l[i][2])):
+    for i,l in enumerate(steps.holdinfo):
+      if l[0] == self.game.dirs.index(direction):
+        if ((curtime - 15.0/steps.playingbpm > l[1])
+            and (curtime < l[2])):
           return i
 
   def check_holds(self, pid, curtime, arrows, steps, judge, toparrfx, holding):
